# Introduction

Phileas is a Python library which helps researchers with the data acquisition
process of automated experiments.

 - **Configurations files**: it uses simple YAML configurations files to
     represent the execution of complex experiments.
 - **Experiment documentation**: its organization provides a clear documentation
     of the operations of an experiment, and allows the experimenter to add
     information to it, as in a lab notebook.
 - **Datasets annotation**: the experiment operations can be easily used to
     annotate the acquired datasets, making the data analysis phase easier.
 - **Complex composable iteration strategies**: the various iteration strategies
     provided can be composed, which allows to quickly and reliably design
     complex experiments.
 - **A transparent instruments driving process**: most of the instrument driving
     tasks can be developed once, and they are then transparently handled by
     phileas.
 - **Experimental setups comparison**: it allows to compare different
     experimental setups, which can be used *e.g.* to troubleshoot replication
     issues
